RegionAttachment

Struct RegionAttachment 

pub struct RegionAttachment<'a> { /* private fields */ }

Implementations

Source

impl<'a> RegionAttachment<'a>

pub fn load_vertices(&self, bone: &Bone<'_>, vertices: &mut [f32; 8])

Loads the 8 vertex positions for this attachments rendering into the provided vertices buffer.

spine-c

Maps to calling spRegionAttachment_computeWorldVertices

pub fn get_vertices(&self, bone: &Bone<'_>) -> [f32; 8]

Returns the 8 vertex positions for this attachments rendering in a new array.

spine-c

Maps to calling spRegionAttachment_computeWorldVertices

pub fn texture_id(&self) -> u32

Returns the u32 texture id which was provided for this image during Atlas loading.

spine-c

Maps to dereferencing ((*spAtlasRegion)spRegionAttachment->rendererObject)->rendererObject

pub fn rotation(&self) -> f32

pub fn color(&self) -> [f32; 4]

pub fn position(&self) -> [f32; 2]

pub fn scale(&self) -> [f32; 2]

pub fn dimensions(&self) -> [f32; 2]

pub fn uv(&self) -> [f32; 8]

pub fn offset(&self) -> [f32; 8]